@@ -55,7 +55,7 @@ class Command(BaseCommand):
             ),
         )
 
-    def handle(self, *args, **options):
+    def handle(self, *_args, **options):
         module = sys.modules[__name__]
         if options.get("loop"):
             while True:
