@@ -82,12 +82,12 @@ class EncryptedTextField(models.TextField):
         encrypted_value = b64d(Fernet(key).encrypt(value.encode()))
         return b64e(b"%b%b" % (salt, encrypted_value)).decode()
 
-    def from_db_value(self, value, *args):
+    def from_db_value(self, value, *_args):
         if value is None:
             return value
         return self.decrypt(value)
 
-    def get_db_prep_value(self, value, *args, **kwargs):
+    def get_db_prep_value(self, value, *_args, **_kwargs):
         if value is None:
             return value
         return self.encrypt(value)
@@ -414,6 +414,7 @@ class Transaction(models.Model):
     
         the user has not yet initiated their transfer to the anchor. This is the 
         necessary first step in any deposit or withdrawal flow.
+
     * **incomplete**
     
         there is not yet enough information for this transaction to be initiated. 
@@ -579,6 +580,15 @@ class Transaction(models.Model):
     This is only used for transactions requiring signatures Polaris cannot
     add itself.
     """
+    claimable_balance_supported = models.BooleanField(default=False)
+    """
+    claimable_balance_supported is a boolean to indicate if the wallet supports the SEP24
+    requirements for handeling claimable balance deposits.
+    """
+    claimable_balance_id = models.TextField(null=True, blank=True)
+    """
+    The ID of the claimable balance used to send funds to the user. This column will be ``None`` if ``claimable_balance_supported`` is ``False`` or if the transaction has not yet been submitted to the Stellar network.
+    """
 
     objects = models.Manager()
 
