@@ -313,6 +313,22 @@ def deposit(account: str, request: Request) -> Response:
     stellar_account = request.POST.get("account")
     lang = request.POST.get("lang")
     sep9_fields = extract_sep9_fields(request.POST)
+    claimable_balance_supported = request.POST.get("claimable_balance_supported")
+    if not claimable_balance_supported:
+        claimable_balance_supported = False
+    elif isinstance(claimable_balance_supported, str):
+        if claimable_balance_supported.lower() not in ["true", "false"]:
+            return render_error_response(
+                _("'claimable_balance_supported' value must be 'true' or 'false'")
+            )
+        claimable_balance_supported = claimable_balance_supported.lower() == "true"
+    elif not isinstance(claimable_balance_supported, bool):
+        return render_error_response(
+            _(
+                "unexpected data type for 'claimable_balance_supprted'. Expected string or boolean."
+            )
+        )
+
     if lang:
         err_resp = validate_language(lang)
         if err_resp:
@@ -368,6 +384,7 @@ def deposit(account: str, request: Request) -> Response:
         status=Transaction.STATUS.incomplete,
         to_address=account,
         protocol=Transaction.PROTOCOL.sep24,
+        claimable_balance_supported=claimable_balance_supported,
         memo=memo,
         memo_type=request.POST.get("memo_type") or Transaction.MEMO_TYPES.hash,
     )
